pub struct GetCacheResult {
pub cached_items: Vec<Bytes>,
pub cache_request_token: Option<CacheRequestTokenV1>,
}Expand description
Result returned to the dispatch handler by either cache’s on_get.
Fields
cached_items: Vec<Bytes>Fresh cached bundles filtered by already_retrieved_peer_ids.
cache_request_token: Option<CacheRequestTokenV1>Issued when the server wants the client to upload after its walk.